@@ -1,6 +1,6 @@
 /* -*- c-basic-offset: 2 -*- */
 /*
-  Copyright(C) 2011-2019 Kouhei Sutou <kou@clear-code.com>
+  Copyright(C) 2011-2020 Sutou Kouhei <kou@clear-code.com>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -36,6 +36,14 @@
 #  define MRN_HAVE_MYSQL_TYPE_BLOB_COMPRESSED
 #endif
 
+#if MYSQL_VERSION_ID >= 80002 && !defined(MRN_MARIADB_P)
+#  define MRN_HAVE_SQL_DD_TYPES_TABLE_H
+#endif
+
+#if MYSQL_VERSION_ID >= 80019 && !defined(MRN_MARIADB_P)
+#  define MRN_HAVE_CREATE_FIELD_H
+#endif
+
 #if MYSQL_VERSION_ID < 50603
   typedef MYSQL_ERROR Sql_condition;
 #endif
@@ -54,6 +62,10 @@
   typedef st_select_lex SELECT_LEX;
 #endif
 
+#if MYSQL_VERSION_ID >= 50607
+#  define MRN_SUPPORT_FOREIGN_KEYS 1
+#endif
+
 #if MYSQL_VERSION_ID >= 50609
 #  define MRN_KEY_HAVE_USER_DEFINED_KEYPARTS
 #endif
@@ -853,3 +865,11 @@ typedef HASH mrn_table_def_cache_type;
 #  define MRN_TABLE_SHARE_RESET(table_share) \
   (memset((table_share), 0, sizeof(TABLE_SHARE)))
 #endif
+
+#if MYSQL_VERSION_ID >= 80019 && !defined(MRN_MARIADB_P)
+#  define MRN_BITMAP_INIT(map, buf, n_bits) \
+    bitmap_init((map), (buf), (n_bits))
+#else
+#  define MRN_BITMAP_INIT(map, buf, n_bits) \
+    bitmap_init((map), (buf), (n_bits), false)
+#endif
